within ;
package Frvs
model HodgkinHuxley
  parameter Real gna = 120;
  // Na conductance
  parameter Real gk = 36;
  parameter Real gleak = 0.3;
  parameter Real c = 1;
  parameter Real vna = -115;
  // Na potential
  parameter Real vk = 12;
  parameter Real vleak = -10.613;
  constant Real eps = 0.0001;
  Boolean p1,p2;
  Real v;
  Real n;
  Real m;
  Real h;
  Real alfan;
  Real alfah;
  Real alfam;
  Real betah;
  Real betan;
  Real betam;
  Real iext;
  parameter Real exc = 20;
  parameter Real inh = 0;
  annotation(experiment(StartTime = 0.0, StopTime = 40, Tolerance = 0.000001));
equation
  iext = -max(exc - inh, 0);
  // % avoiding NaN - eps is not good in this case, while 1/eps = inf, but this
  // % converges to 0.1 See:
  // % %
  // % figure;% hold on;
  // % x = 9:.01:11;
  // % f = @(x) 0.01*(10-x)./(exp((10-x)/10) -1);
  // % fe = @(x) 0.01*(10-x)./(exp((10-x)/10) -1 + eps);
  // % plot(x, f(x));plot(x, fe(x), 'r:');
  // %%
  if v > -10 - eps and v < -10 + eps then
    alfan = 0.1;
    p1 = true;
  else
    alfan = (0.01 * (10 + v)) / (exp((10 + v) / 10) - 1);
    p1 = false;
  end if;
  betan = 0.125 * exp(v / 80);
  //% avoiding NaN
  if v > -25 - eps and v < -25 + eps then
    alfam = 1;
    p2 = true;
  else
    alfam = (0.1 * (25 + v)) / (exp((25 + v) / 10) - 1);
    p2 = false;
  end if;
  betam = 4 * exp(v / 18);
  alfah = 0.07 * exp(v / 20);
  betah = 1 / (exp((30 + v) / 10) + 1);
  der(v) = (-gna * m ^ 3 * h * (v - vna) - gk * n ^ 4 * (v - vk) - gleak * (v - vleak) + iext) / c;
  der(n) = alfan * (1 - n) - betan * n;
  der(m) = alfam * (1 - m) - betam * m;
  der(h) = alfah * (1 - h) - betah * h;
end HodgkinHuxley;
end Frvs;

